@@ -27,11 +27,6 @@
  */
 
 #ifdef _WIN32
-#ifndef __MINGW32__
-#include <stdio.h>
-#define snprintf(str, n, format, ...) \
-  _snprintf_s(str, n, _TRUNCATE, format, ##__VA_ARGS__)
-#endif
 #define strcasecmp  stricmp
 #define strncasecmp  strnicmp
 #endif
